@@ -85,7 +85,7 @@ class MetaFetcher:
                         call_kwargs=task_kwargs,
                         region_name=region_name,
                     )
-                    queue.put(list(resources), timeout=60 * 3)
+                    queue.put(list([dict(resource, **task_kwargs) for resource in resources]), timeout=60 * 3)
 
                 # Ends worker life.
                 except Empty:
@@ -118,26 +118,22 @@ class MetaFetcher:
         metadata_config = self.metadata_config(metadata_type)
         call_kwargs = thaw(metadata_config.get("kwargs", {}))
 
-        try:
-            if "parent_required_filters" in metadata_config:
-                yield from self.fetch_in_threads(
-                    metadata_config=metadata_config,
-                    call_kwargs=call_kwargs,
-                    metadata_type=metadata_type,
-                    region_name=region_name,
-                    required_filters=required_filters,
-                    num_threads=num_threads,
-                )
-            else:
-                yield from resource_listing(
-                    session=self.session,
-                    metaname=metadata_type,
-                    fetch_method=metadata_config["fetch_method"],
-                    response_key=metadata_config.get("response_key"),
-                    page_key=metadata_config.get("page_key", ""),
-                    call_kwargs=custom_kwargs or call_kwargs,
-                    region_name=region_name,
-                )
-        except Exception as e:
-            logging.exception(f"[{datetime.now()}] metadata_producer {region_name} region fetch error: {e}", exc_info=False)
-            yield from iter([])
+        if "parent_required_filters" in metadata_config:
+            yield from self.fetch_in_threads(
+                metadata_config=metadata_config,
+                call_kwargs=call_kwargs,
+                metadata_type=metadata_type,
+                region_name=region_name,
+                required_filters=required_filters,
+                num_threads=num_threads,
+            )
+        else:
+            yield from resource_listing(
+                session=self.session,
+                metaname=metadata_type,
+                fetch_method=metadata_config["fetch_method"],
+                response_key=metadata_config.get("response_key"),
+                page_key=metadata_config.get("page_key", ""),
+                call_kwargs=custom_kwargs or call_kwargs,
+                region_name=region_name,
+            )
